@@ -12,7 +12,7 @@ namespace mixal {
  * 
  * @see overflow
  */
-void Machine::executeNUM() {
+void Computer::executeNUM() {
     int64_t num = 0;
     for (int i = 1; i <= 5; ++i) {
         num = num * 10 + rA[i] % 10;
@@ -30,7 +30,7 @@ void Machine::executeNUM() {
 }
 
 /** Convert number in rA to chars, and save the result to rA and rX. */
-void Machine::executeCHAR() {
+void Computer::executeCHAR() {
     int32_t num = std::abs(rA.value());
     for (int i = 5; i >= 1; --i) {
         rX[i] = 30 + num % 10;
