@@ -9,13 +9,13 @@
 namespace mixal {
 
 /** Load the word from the address to rA or rX. */
-void Machine::executeLD(const InstructionWord& instruction, Register5* reg) {
+void Computer::executeLD(const InstructionWord& instruction, Register5* reg) {
     int address = getIndexedAddress(instruction, true);
     copyToRegister5(instruction, memory[address], reg);
 }
 
 /** Load the word from the address to rI. */
-void Machine::executeLDi(const InstructionWord& instruction) {
+void Computer::executeLDi(const InstructionWord& instruction) {
     int address = getIndexedAddress(instruction, true);
     int registerIndex = instruction.operation() - Instructions::LD1 + 1;
     auto& rIi = rI(registerIndex);
@@ -23,13 +23,13 @@ void Machine::executeLDi(const InstructionWord& instruction) {
 }
 
 /** Load negative value of the word from the address to rA or rX. */
-void Machine::executeLDN(const InstructionWord& instruction, Register5* reg) {
+void Computer::executeLDN(const InstructionWord& instruction, Register5* reg) {
     executeLD(instruction, reg);
     reg->negative = !reg->negative;
 }
 
 /** Load negative value of the word from the address to rI. */
-void Machine::executeLDiN(const InstructionWord& instruction) {
+void Computer::executeLDiN(const InstructionWord& instruction) {
     int address = getIndexedAddress(instruction, true);
     int registerIndex = instruction.operation() - Instructions::LD1N + 1;
     auto& rIi = rI(registerIndex);
